'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _reactIntl = require('react-intl');

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _cspaceLayout = require('cspace-layout');

var _CancelButton = require('../navigation/CancelButton');

var _CancelButton2 = _interopRequireDefault(_CancelButton);

var _RunButton = require('../record/RunButton');

var _RunButton2 = _interopRequireDefault(_RunButton);

var _RunReportButton = require('../../../styles/cspace-ui/RunReportButton.css');

var _RunReportButton2 = _interopRequireDefault(_RunReportButton);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const messages = (0, _reactIntl.defineMessages)({
  prompt: {
    'id': 'reportModal.prompt',
    'defaultMessage': 'Run this report?'
  },
  unsaved: {
    'id': 'reportModal.unsaved',
    'defaultMessage': 'This record has changes that have not been saved. The report will not include any unsaved data.'
  },
  cancel: {
    'id': 'reportModal.cancel',
    'defaultMessage': 'Cancel'
  },
  run: {
    'id': 'reportModal.run',
    'defaultMessage': 'Run'
  }
});

const propTypes = {
  isOpen: _propTypes2.default.bool,
  isRecordModified: _propTypes2.default.bool,
  reportItem: _propTypes2.default.instanceOf(_immutable2.default.Map),
  onCancelButtonClick: _propTypes2.default.func,
  onCloseButtonClick: _propTypes2.default.func,
  onRunButtonClick: _propTypes2.default.func
};

class ReportModal extends _react.Component {
  constructor() {
    super();

    this.renderButtonBar = this.renderButtonBar.bind(this);
  }

  renderButtonBar() {
    var _props = this.props;
    const onCancelButtonClick = _props.onCancelButtonClick,
          onRunButtonClick = _props.onRunButtonClick;


    return _react2.default.createElement(
      'div',
      null,
      _react2.default.createElement(_CancelButton2.default, {
        label: _react2.default.createElement(_reactIntl.FormattedMessage, messages.cancel),
        onClick: onCancelButtonClick
      }),
      _react2.default.createElement(_RunButton2.default, {
        className: _RunReportButton2.default.common,
        label: _react2.default.createElement(_reactIntl.FormattedMessage, messages.run),
        onClick: onRunButtonClick
      })
    );
  }

  render() {
    var _props2 = this.props;
    const isOpen = _props2.isOpen,
          isRecordModified = _props2.isRecordModified,
          reportItem = _props2.reportItem,
          onCloseButtonClick = _props2.onCloseButtonClick;


    if (!isOpen || !reportItem) {
      return null;
    }

    let unsavedWarning;

    if (isRecordModified) {
      unsavedWarning = _react2.default.createElement(
        'p',
        null,
        _react2.default.createElement(_reactIntl.FormattedMessage, messages.unsaved)
      );
    }

    return _react2.default.createElement(
      _cspaceLayout.Modal,
      {
        isOpen: isOpen,
        title: _react2.default.createElement(
          'h1',
          null,
          reportItem.get('name')
        ),
        closeButtonClassName: 'material-icons',
        closeButtonLabel: 'close',
        renderButtonBar: this.renderButtonBar,
        onCloseButtonClick: onCloseButtonClick
      },
      _react2.default.createElement(_reactIntl.FormattedMessage, messages.prompt),
      unsavedWarning
    );
  }
}

exports.default = ReportModal;
ReportModal.modalName = 'ReportModal';
ReportModal.propTypes = propTypes;